# ziptag [![Build Status](https://travis-ci.org/FoKo/ziptag.svg?branch=master)](https://travis-ci.org/FoKo/ziptag) [![codecov](https://codecov.io/gh/FoKo/ziptag/branch/master/graph/badge.svg)](https://codecov.io/gh/FoKo/ziptag) [![Greenkeeper badge](https://badges.greenkeeper.io/FoKo/ziptag.svg)](https://greenkeeper.io/)

Fast RFC-7232 compliant etags for JSON.

[![NPM](https://nodei.co/npm/ziptag.png?downloads=true&downloadRank=true&stars=true)](https://nodei.co/npm/ziptag/)

## Installation

Available through npm: `npm install --save ziptag`.

## Usage

This module exports a single function which takes any value
as input and returns a valid ETag as a string.

*The code is written in ES6. If you are not using the ES6
import, then you must use the `default` method that is exported.*

### `ziptag(object, [ignorePaths], [maxDepth]) => string`

Examples:

```javascript
const ziptag = require('ziptag').default

// W/"e21zZzonaGVsbG8gd29ybGQn"
ziptag({ msg: 'hello world' })

// W/"e25hbWU6J0pvaG4nYWdlOjIwYmRheTow"
ziptag({ name: 'John', age: 20, bday: new Date(0) })

// W/"e3BlcnNvbjp7bmFtZTonSm9obidhZ2U6MjBiZGF5OjA="
ziptag({
  person: {
    name: 'John',
    age: 20,
    bday: new Date(0)
  }
})
```

### Parameters

 - **ignorePaths**: a map of paths to ignore, value of the key to
 ignore should be false. Example: `{ "path.to.key": false }`
 - **maxDepth**: the maximum depth to traverse in the entity.
 This is not protection against circular objects so setting this
 to Infinity will work (it'll just be really slow for large objects).

## Considerations

### It's dirty

This module is designed to create a very *dirty* etag as fast
as possible. Due to this, higher priority is given to performance
than collision avoidance. As with any hash function, there are
collisions. Though there will be many more collisions than with
a stronger solution like `JSON.stringify` (which still has
collisions but significantly less). However, it will outperform
the native JSON stringify.

### It's really fast

To see up-to-date benchmark results, check out the
[travis log](https://travis-ci.org/FoKo/ziptag).

### Larger objects = larger etags

Makes sense, right?

## License

Copyright &copy; 2017-present Foko Inc. All rights reserved.

Licensed under the [MIT license](LICENSE.md).
