/**
 * @file test/helpers/randomObj.js
 * @license MIT
 * @copyright 2017-present Foko Inc.
 */

import { generate as randomstring } from 'randomstring'

const TYPES = {
  'string': () => randomstring(),
  'int': () => (Math.random() * Number.MAX_SAFE_INTEGER)|0,
  'double': () => Math.random() * Number.MAX_VALUE,
  'regex': () => new RegExp(randomstring()),
  'function': () => () => 0,
  'date': () => new Date((Date.now() * Math.random())|0),
  'object': null
}

const TYPES_KEYS = Object.keys(TYPES)

let genObjects

/**
 * Generates a random object using random type generators
 * from `TYPES`.
 * @param {Number} [MAX_OBJECTS=100] internally used to track number of values to be generated
 * @returns randomly generated object
 */
function randomObj (MAX_OBJECTS = 100, MAX_KEYS = 1000) {
  if ((++genObjects) >= MAX_OBJECTS) return Object.create(null)

  const o = Object.create(null)
  const keys = Math.round(Math.random() * MAX_KEYS)

  for (let i = 0; i < keys; ++ i) {
    const type = TYPES_KEYS[(Math.random() * TYPES_KEYS.length)|0]
    o[randomstring()] = type === 'object' ? randomObj(MAX_OBJECTS, MAX_KEYS) : TYPES[type]()
  }

  return o
}

/**
 * Proxy for 'randomObj' that resets the object counter then generates
 * a new random object.
 * @param {Number} MAX_OBJECTS the maximum number of values that should be generated
 */
export default function generateRandomObject (MAX_OBJECTS, MAX_KEYS) {
  genObjects = 0
  return randomObj(MAX_OBJECTS, MAX_KEYS)
}