import test from 'ava'
import ziptag from '../'
import random from './helpers/randomObj'

// test for RFC 7230 compliance
// Source: https://tools.ietf.org/html/rfc7232#section-2.3
const RFC_WEAK_ETAG = /(W\/)?"(.*)"/
const RFC_INVALID_CHARS = /[^\x21\x23-\x7E\x80-\xFF]/

test('should produce RFC 7230 compliant etags', t => {
  for (let i = 0; i < 10; ++ i) {
    const etag = ziptag(random())
    const [_, __, etagc] = etag.match(RFC_WEAK_ETAG)

    t.regex(etag, RFC_WEAK_ETAG, 'etag should be marked as weak')
    t.notRegex(etagc, RFC_INVALID_CHARS, 'etagc should only have valid characters')
  }
})
